Exception: Forem::ConflictError

Inherits:
ForemError
  • Object
show all
Defined in:
lib/forem/errors.rb

Overview

Raised when the server responds with HTTP 409 Conflict.

Usually indicates a duplicate resource or a state conflict (e.g. trying to publish an article that is already published).

Instance Attribute Summary

Attributes inherited from ForemError

#code, #http_body, #http_headers, #http_status

Method Summary

Methods inherited from ForemError

#initialize

Constructor Details

This class inherits a constructor from Forem::ForemError