Class: Forem::PodcastEpisode
- Inherits:
-
APIResource
- Object
- ForemObject
- APIResource
- Forem::PodcastEpisode
- Extended by:
- APIOperations::List
- Defined in:
- lib/forem/resources/podcast_episode.rb
Overview
Represents a podcast episode published on a Forem instance.
Podcast episodes are audio content items associated with a podcast channel. The public API supports listing episodes, optionally filtered by username (the podcast owner) or a specific podcast slug.
Returns active episodes from published podcasts, ordered by descending publication date. Default: 30 per page.
Available operations (via mixins):
- +List+ — GET /api/podcast_episodes
List Parameters
username(String) — Retrieve episodes from a specific podcast (e.g.,'codenewbie')page(Integer) — Page number (default: 1)per_page(Integer) — Items per page (default: 30)
Constant Summary collapse
- OBJECT_NAME =
"podcast_episode"- RESOURCE_PATH =
"/api/podcast_episodes"
Instance Attribute Summary
Attributes inherited from ForemObject
Method Summary
Methods included from APIOperations::List
Methods inherited from APIResource
#refresh, resource_path, #resource_url
Methods inherited from ForemObject
#==, #[], #[]=, construct_from, cursor_list, #initialize, #inspect, #method_missing, paginated_list, #respond_to_missing?, #to_hash
Methods included from APIOperations::Request
Constructor Details
This class inherits a constructor from Forem::ForemObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Forem::ForemObject