Class: Forem::Tag
- Inherits:
-
APIResource
- Object
- ForemObject
- APIResource
- Forem::Tag
- Extended by:
- APIOperations::List
- Defined in:
- lib/forem/resources/tag.rb
Overview
Represents a Forem tag used to categorize articles.
Tags are keywords attached to articles that help readers discover related content. Only listing is supported through the public API; tags are created implicitly when articles are published with new tag names.
Tags are ordered by popularity. Default: 10 per page.
Available operations (via mixins):
- +List+ — GET /api/tags
Constant Summary collapse
- OBJECT_NAME =
"tag"- RESOURCE_PATH =
"/api/tags"
Instance Attribute Summary
Attributes inherited from ForemObject
Method Summary
Methods included from APIOperations::List
Methods inherited from APIResource
#refresh, resource_path, #resource_url
Methods inherited from ForemObject
#==, #[], #[]=, construct_from, cursor_list, #initialize, #inspect, #method_missing, paginated_list, #respond_to_missing?, #to_hash
Methods included from APIOperations::Request
Constructor Details
This class inherits a constructor from Forem::ForemObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Forem::ForemObject