Class: Forem::Video
- Inherits:
-
APIResource
- Object
- ForemObject
- APIResource
- Forem::Video
- Extended by:
- APIOperations::List
- Defined in:
- lib/forem/resources/video.rb
Overview
Represents an article with an associated video on a Forem instance.
Video articles are a special content type where the primary content is a video rather than text. The public API supports listing video articles, returned ordered by publication date.
Returns published articles with video, ordered by descending popularity. Default: 24 per page.
Available operations (via mixins):
- +List+ — GET /api/videos
Constant Summary collapse
- OBJECT_NAME =
"video"- RESOURCE_PATH =
"/api/videos"
Instance Attribute Summary
Attributes inherited from ForemObject
Method Summary
Methods included from APIOperations::List
Methods inherited from APIResource
#refresh, resource_path, #resource_url
Methods inherited from ForemObject
#==, #[], #[]=, construct_from, cursor_list, #initialize, #inspect, #method_missing, paginated_list, #respond_to_missing?, #to_hash
Methods included from APIOperations::Request
Constructor Details
This class inherits a constructor from Forem::ForemObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Forem::ForemObject